<?php

namespace Teknisa\ACL\Util;

use Zeedhi\Framework\DependencyInjection\InstanceManager;
use Zeedhi\Framework\HTTP\Kernel;
use Teknisa\Libs\Util\Environment;
use Zeedhi\ZhuLog\Logger\LoggerInfoProvider;

class LoggerInfoProviderImpl implements LoggerInfoProvider {
    /** @var Environment $environment */
    private $environment;
    /** @var Kernel $kernel */
    private $kernel;

    public function __construct(Environment $environment, Kernel $kernel) {
        $this->environment = $environment;
        $this->kernel      = $kernel;
    }

    /**
     * Returns the User ID.
     *
     * @return mixed
     */
    public function getUserId() {
        return $this->environment->getCurrentUserId();
    }

    /**
     * Returns the Organization ID.
     *
     * @return mixed
     */
    public function getOrganizationId() {
        return $this->environment->getCurrentOrganizationId();
    }

    /**
     * Returns the Product ID.
     *
     * @return mixed
     */
    public function getProductId() {
        return InstanceManager::getInstance()->getParameter('projectId');
    }

    /**
     * Returns the Container name.
     *
     * @return string
     */
    public function getContainerName() {
        $requestOrigin = $this->kernel->getHttpRequest()->get('origin');
        return isset($requestOrigin['containerLabel']) ? $requestOrigin['containerLabel'] : '';
    }

    /**
     * Returns the Widget name.
     *
     * @return string
     */
    public function getWidgetName() {
        $requestOrigin = $this->kernel->getHttpRequest()->get('origin');
        return isset($requestOrigin['widgetLabel']) ? $requestOrigin['widgetLabel'] : '';
    }
} 